# - Config to retrieve all components of the ignition-gazebo4 package
#
# This should only be invoked by ignition-gazebo4-config.cmake.
#
# To retrieve this meta-package, use:
# find_package(ignition-gazebo4 COMPONENTS all)
#
# This creates the target ignition-gazebo4::all which will link to all known
# components of ignition-gazebo4, including the core library.
#
# This also creates the variable ignition-gazebo4_ALL_LIBRARIES
#
################################################################################

cmake_minimum_required(VERSION 3.10.2 FATAL_ERROR)

if(ignition-gazebo4_ALL_CONFIG_INCLUDED)
  return()
endif()
set(ignition-gazebo4_ALL_CONFIG_INCLUDED TRUE)

if(NOT ignition-gazebo4-all_FIND_QUIETLY)
  message(STATUS "Looking for all libraries of ignition-gazebo4 -- found version 4.0.0")
endif()


####### Expanded from @PACKAGE_INIT@ by configure_package_config_file() #######
####### Any changes to this file will be overwritten by the next CMake run ####
####### The input file was ignition-all-config.cmake.in                            ########

get_filename_component(PACKAGE_PREFIX_DIR "${CMAKE_CURRENT_LIST_DIR}/../../../../" ABSOLUTE)

# Use original install prefix when loaded through a "/usr move"
# cross-prefix symbolic link such as /lib -> /usr/lib.
get_filename_component(_realCurr "${CMAKE_CURRENT_LIST_DIR}" REALPATH)
get_filename_component(_realOrig "/usr/lib/aarch64-linux-gnu/cmake/ignition-gazebo4-all" REALPATH)
if(_realCurr STREQUAL _realOrig)
  set(PACKAGE_PREFIX_DIR "/usr")
endif()
unset(_realOrig)
unset(_realCurr)

macro(set_and_check _var _file)
  set(${_var} "${_file}")
  if(NOT EXISTS "${_file}")
    message(FATAL_ERROR "File or directory ${_file} referenced by variable ${_var} does not exist !")
  endif()
endmacro()

macro(check_required_components _NAME)
  foreach(comp ${${_NAME}_FIND_COMPONENTS})
    if(NOT ${_NAME}_${comp}_FOUND)
      if(${_NAME}_FIND_REQUIRED_${comp})
        set(${_NAME}_FOUND FALSE)
      endif()
    endif()
  endforeach()
endmacro()

####################################################################################

# Get access to the find_dependency utility
include(CMakeFindDependencyMacro)

# Find the core library
find_dependency(ignition-gazebo4 4.0.0 EXACT)

# Find the component libraries
find_dependency(ignition-gazebo4-rendering 4.0.0 EXACT)
find_dependency(ignition-gazebo4-gui 4.0.0 EXACT)
find_dependency(ignition-gazebo4-air-pressure-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-altimeter-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-apply-joint-force-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-linearbatteryplugin-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-breadcrumbs-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-buoyancy-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-contact-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-camera-video-recorder-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-detachable-joint-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-diff-drive-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-follow-actor-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-imu-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-joint-controller-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-joint-position-controller-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-joint-state-publisher-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-lift-drag-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-log-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-log-video-recorder-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-logical-camera-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-magnetometer-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-multicopter-motor-model-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-multicopter-control-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-performer-detector-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-physics-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-pose-publisher-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-scene-broadcaster-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-sensors-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-thermal-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-touchplugin-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-triggered-publisher-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-user-commands-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-velocity-control-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-wind-effects-system 4.0.0 EXACT)
find_dependency(ignition-gazebo4-ign 4.0.0 EXACT)

if(NOT TARGET ignition-gazebo4::ignition-gazebo4-all)
  include("${CMAKE_CURRENT_LIST_DIR}/ignition-gazebo4-all-targets.cmake")

  add_library(ignition-gazebo4::all INTERFACE IMPORTED)
  set_target_properties(ignition-gazebo4::all PROPERTIES
    INTERFACE_LINK_LIBRARIES "ignition-gazebo4::ignition-gazebo4-all")

endif()

# Create the "requested" target if it does not already exist
if(NOT TARGET ignition-gazebo4::requested)
  add_library(ignition-gazebo4::requested INTERFACE IMPORTED)
endif()

# Link the "all" target to the "requested" target
get_target_property(ign_requested_components ignition-gazebo4::requested INTERFACE_LINK_LIBRARIES)
if(NOT ign_requested_components)
  set_target_properties(ignition-gazebo4::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "ignition-gazebo4::ignition-gazebo4-all")
else()
  set_target_properties(ignition-gazebo4::requested PROPERTIES
    INTERFACE_LINK_LIBRARIES "${ign_requested_components};ignition-gazebo4::ignition-gazebo4-all")
endif()

set(ignition-gazebo4_ALL_LIBRARIES ignition-gazebo4::ignition-gazebo4-all)
